__author__ = 'Stefen Shawn'
__license__ = 'MIT'
__address__ = "www.github.com/StepfenShawn/Cantonese"
__label__ = "Support While Stmt in VM"
name = "Cantonese"